# vacolba-looker-data

Build Package
-
>`python -m build `
Upload Package

> `python -m twine upload --repository pypi dist/*`


twine upload dist/* -u __token__ -p pypi-AgEIcHlwaS5vcmcCJDUxYjVkZmE3LTk1MTEtNDBkNC05MTA3LWI1NzFmNmI5NjMwOQACF1sxLFsiZ2V0LWxvb2tlci1kYXRhIl1dAAIsWzIsWyJiYWQ1NGEzYi02YzM1LTRjZTItYjgwMC0zNjE3NjliOTBjYWIiXV0AAAYga8buqyIgSDk5l2kWGNi4_I2xLwf8AXoghthIIPE8C8M